@@ -964,6 +964,16 @@ class RemoteJob(object):
     def job_id(self):
         return self._job_id
 
+    def finish(self, submit=True):
+        """
+        Optionally submits and marks a job as finished. Useful for letting all interested parties know the job is done. 
+        This locks the job and no further actions will be possible (writing, adding logs).
+
+        :param submit: submit the current cached data to server before finishing job
+        """
+        self.submit()
+        self._conn.raw.post('/jobs/{}/finish'.format(self.job_id))
+
     def _init_get_series_dict(self, series, incr_bulk=False):
         if not self._values.has_key(series):
             self._values[series] = {'fields': {}, 'points': {}}
@@ -1114,6 +1124,13 @@ class RemoteJob(object):
         for fn in self._post_hooks:
             fn(job_id=self.job_id, response=response)
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.finish()
+        return exc_type, exc_val, exc_tb
+
 
 class GetBulk(object):
     """
